@@ -3,12 +3,16 @@
 wallyplot.default <- function(x, y=x, FUN=residualplot,
                               hide=TRUE,
                               simulateFunction=rnorm,
+			      model=NULL,
                               ...) {
 
   simulateFunction <- match.fun(simulateFunction)
 
-  if (is.vector(y) && length(x)==length(y))
-    y <- cbind(y, sapply(1:8, function(k) {simulateFunction(length(x))}))
+  if (is.vector(y) && length(x)==length(y)) {
+    if (!is.null(model))  # If an lm/glm object was given to model then simulate from that model
+      y <- cbind(y, sapply(1:8, function(k) {simulateFunction(model)}))
+    else y <- cbind(y, sapply(1:8, function(k) {simulateFunction(length(x))}))    
+  }
 
   if (!is.numeric(x) || !is.matrix(y))
     stop("x and y input must be a vector and matrix, respectively")
@@ -32,20 +36,39 @@ wallyplot.default <- function(x, y=x, FUN=residualplot,
   invisible(NULL)
 }
 
+#
+# Simulate residuals from an lm object with the (slight dependence) they will exhibit
+#
+lmsimresiduals <- function(L) {
+  if (!inherits(L, 'lm'))
+    stop("L must be a glm/lm output!")
+  
+  data <- L$model
+  data[[1]] <- simulate(L, nsim = 1)[[1]]
+  r <- L$call
+  r["data"] <- NULL # remove references to existing data frames
+  L.ny <- eval(r, envir = data)
+  rstandard(L.ny)
+}
+
+
+
 
 #' @import graphics
 #' @rdname wallyplot
 #' @export
-wallyplot.lm <- function(x, y=x, FUN=residualplot,
+wallyplot.lm <- function(x,
+                         y=x,
+			 FUN=residualplot,
 	                 hide=TRUE,
-                         simulateFunction=rnorm,
+                         simulateFunction=lmsimresiduals,
                          ...) {
 
   # Extract information from model fit
+  xp <- predict(x)
   y <- rstandard(x)
-  x <- predict(x)
 
-  wallyplot.default(x, y, FUN=FUN, hide=hide, simulateFunction=simulateFunction, ...)
+  wallyplot.default(xp, y, FUN=FUN, hide=hide, simulateFunction=simulateFunction, model=x, ...)
 }
 
 
@@ -93,6 +116,7 @@ wallyplot.lm <- function(x, y=x, FUN=residualplot,
 #' then the true residual plot is shown in the center.
 #' @param simulateFunction The function used to produce y values under the null
 #' hypothesis. Defaults to rnorm
+#' @param model Optional input to simulateFunction
 #' @param ... Other arguments passed to the plot function \code{FUN}
 #' @author Claus Ekstrom \email{claus@@rprimer.dk}
 #' @references Ekstrom, CT (2014) \emph{Teaching 'Instant Experience' with
